# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/test/work_flow/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/test/work_flow/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Test\\WorkFlow\\": "packages/test/work_flow/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Test\WorkFlow\Providers\WorkFlowServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'WorkFlow'  => Test\WorkFlow\Facades\WorkFlow::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Test\\WorkFlowTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Test\WorkFlow\Providers\WorkFlowServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Test\WorkFlow\Providers\WorkFlowServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Test\WorkFlow\Providers\WorkFlowServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/work_flow/{modulename}

**User**

    http://path-to-route-folder/user/work_flow/{modulename}

**Public**

    http://path-to-route-folder/work_flows


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/work_flow/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/work_flow/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/work_flow/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/work_flow/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/work_flow/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/work_flow/{modulename}/{slug}
    METHOD: GET